==> zio-aws-apigatewayv2_3-5.17.129.2-sources.jar: zio/aws/apigatewayv2/model/DeleteIntegrationRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteIntegrationRequest(
    apiId: __string,
    integrationId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest = {
    import DeleteIntegrationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .integrationId(__string.unwrap(integrationId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteIntegrationRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteIntegrationRequest.wrap(buildAwsValue())
}
object DeleteIntegrationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteIntegrationRequest =
      zio.aws.apigatewayv2.model.DeleteIntegrationRequest(apiId, integrationId)
    def apiId: __string
    def integrationId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getIntegrationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(integrationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest
  ) extends zio.aws.apigatewayv2.model.DeleteIntegrationRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val integrationId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.integrationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest
  ): zio.aws.apigatewayv2.model.DeleteIntegrationRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_3-5.17.195.3-sources.jar: zio/aws/apigatewayv2/model/DeleteIntegrationRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteIntegrationRequest(
    apiId: __string,
    integrationId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest = {
    import DeleteIntegrationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .integrationId(integrationId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.DeleteIntegrationRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteIntegrationRequest.wrap(buildAwsValue())
}
object DeleteIntegrationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteIntegrationRequest =
      zio.aws.apigatewayv2.model.DeleteIntegrationRequest(apiId, integrationId)
    def apiId: __string
    def integrationId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getIntegrationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(integrationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest
  ) extends zio.aws.apigatewayv2.model.DeleteIntegrationRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val integrationId: __string = impl.integrationId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteIntegrationRequest
  ): zio.aws.apigatewayv2.model.DeleteIntegrationRequest.ReadOnly = new Wrapper(
    impl
  )
}
